commit 83ac15470614ceefa4bd8f184f3e625ea51998b2
Author: Juergen Spitzmueller <sp...@lyx.org>
Date:   Sat Dec 31 19:45:25 2016 +0100

    TeXFiles.py: scan for biblatex *.bbx and *.cbx files
---
 lib/scripts/TeXFiles.py |   21 ++++++++++++++++-----
 1 files changed, 16 insertions(+), 5 deletions(-)

diff --git a/lib/scripts/TeXFiles.py b/lib/scripts/TeXFiles.py
index 9e6f6b5..31b44b4 100755
--- a/lib/scripts/TeXFiles.py
+++ b/lib/scripts/TeXFiles.py
@@ -16,17 +16,20 @@
 # TeX style files      -> option sty
 # bibtex style files   -> option bst
 # bibtex database files -> option bib
+# biblatex bibstyles   -> option bbx
+# biblatex citestyles  -> option cbx
 #
 # with the help
 # of kpsewhich and creates a
 # bstFiles.lst, clsFiles.lst, styFiles.lst, bibFiles.lst
 # without any parameter all files are created.
 #
 # Herbert Voss <v...@perce.org>
 #
 # Updates from Jean-Marc Lasgouttes.
 #
 # bib support added by Juergen Spitzmueller (v0.3)
 #
 # translated to python by Bo Peng, so that the script only 
 # relies on python and kpsewhich (no shell command is used).
@@ -38,6 +41,8 @@ cls_stylefile = 'clsFiles.lst'
 sty_stylefile = 'styFiles.lst'
 bst_stylefile = 'bstFiles.lst'
 bib_files = 'bibFiles.lst'
+bbx_files = 'bbxFiles.lst'
+cbx_files = 'cbxFiles.lst'
 
 def cmdOutput(cmd):
     '''utility function: run a command and get its output as a string
@@ -51,19 +56,19 @@ def cmdOutput(cmd):
 # processing command line options
 if len(sys.argv) > 1:
     if sys.argv[1] in ['--help', '-help']:
-        print '''Usage: TeXFiles.py [-version | cls | sty | bst | bib ]
+        print '''Usage: TeXFiles.py [-version | cls | sty | bst | bib | bbx| 
cbx ]
             Default is without any Parameters,
             so that all files will be created'''
         sys.exit(0)
     else:
         types = sys.argv[1:]
         for type in types:
-            if type not in ['cls', 'sty', 'bst', 'bib']:
+            if type not in ['cls', 'sty', 'bst', 'bib', 'bbx', 'cbx']:
                 print 'ERROR: unknown type', type
                 sys.exit(1)
 else:
     # if no parameter is specified, assume all
-    types = ['cls', 'sty', 'bst', 'bib']
+    types = ['cls', 'sty', 'bst', 'bib', 'bbx', 'cbx']
 
 #
 # MS-DOS and MS-Windows define $COMSPEC or $ComSpec and use `;' to separate
@@ -92,6 +97,12 @@ for type in types:
     elif type == 'bib':
         outfile = bib_files
         kpsetype = '.bib'
+    elif type == 'bbx':
+        outfile = bbx_files
+        kpsetype = '.tex'
+    elif type == 'cbx':
+        outfile = cbx_files
+        kpsetype = '.tex'
 
     dirs = cmdOutput('kpsewhich --show-path=' + kpsetype).replace('!!', 
@@ -16,17 +16,20 @@
 # with the help
 # of kpsewhich and creates a
-# bstFiles.lst, clsFiles.lst, styFiles.lst, bibFiles.lst
+# bstFiles.lst, clsFiles.lst, styFiles.lst, bibFiles.lst,
+# bbxFiles.lst, cbxFiles.lst
 # without any parameter all files are created.
 #
@@ -16,17 +16,20 @@
 # Updates from Jean-Marc Lasgouttes.
 #
-# bib support added by Juergen Spitzmueller (v0.3)
+# bib, bbx and cbx support added by Juergen Spitzmueller (v0.4)
 #
 # translated to python by Bo Peng, so that the script only 
'').strip()
     # remove excessive //

Reply via email to